DEBUG <- 0

## Bobcats team stats vs Wizards (2-11-2009)
#team <- data.frame(min=240,fgm=37,fga=74,fg3m=11,fg3a=27,ftm=16,fta=21,oreb=10,dreb=32,treb=42,ast=28,pf=17,st=10,to=16,blocks=11,bas=4,pts=101)
#opp <- data.frame(min=240,fgm=35,fga=84,fg3m=9,fg3a=18,ftm=10,fta=13,oreb=13,dreb=25,treb=38,ast=24,pf=19,st=9,to=16,blocks=4,bas=11,pts=89)

## R. Felton
#player <- data.frame(min=45+(25/60),fgm=7,fga=16,fg3m=1,fg3a=3,ftm=0,fta=0,oreb=1,dreb=7,treb=8,ast=9,pf=2,st=5,to=4,blocks=1,bas=1,pts=15)

# individual scoring possessions
"nba.isp" <- function(team,player) {
	FG_part <- player$fgm * (1 - 0.5 * (player$pts - player$fgm) / (2 * player$fga) * player$Q_ast)
	AST_part <- 0.5 * ( ((team$pts - team$ftm) - (player$pts - player$ftm)) / (2 * (team$fga - player$fga)) ) * player$ast
	FT_part <- (1 - (1 - player$ftp)^2) * 0.4 * player$fta
	OR_part <- player$oreb * team$oreb_weight * team$play_pct

	scoring_poss <- (FG_part + AST_part + FT_part) * (1 - (team$oreb / team$scoring_poss) * team$oreb_weight * team$play_pct) + OR_part

	if (DEBUG) {
		cat("Q_ast = ",player$Q_ast,"\n",sep="")
		cat("--> Q_5 = ",player$Q_5,"\n",sep="")
		cat("--> Q_12 = ",player$Q_12,"\n",sep="")
		cat("FG_part = ",FG_part,"\n",sep="")
		cat("AST_part = ",AST_part,"\n",sep="")
		cat("FT_part = ",FT_part,"\n",sep="")
		cat("OR_part = ",OR_part,"\n",sep="")
		cat("ISP = ",scoring_poss,"\n",sep="")
	}

	return(scoring_poss)
}

# individual total possessions
"nba.itp" <- function(team,player) {
	Missed_FG_part <- (player$fga - player$fgm) * (1 - 1.07 * team$oreb_pct)
	Missed_FT_part <- (1 - player$ftp)^2 * 0.4 * player$fta

	total_poss <- player$scoring_poss + Missed_FG_part + Missed_FT_part + player$to

	if (DEBUG) {
		cat("Missed_FG_part = ",Missed_FG_part,"\n",sep="")
		cat("Missed_FT_part = ",Missed_FT_part,"\n",sep="")
		cat("ITP = ",total_poss,"\n",sep="")
	}

	return(total_poss)
}

# individual points produced
"nba.ipp" <- function(team,player) {
	FG_part <- 2 * (player$fgm + 0.5 * player$fg3m) * (1 - 0.5 * ((player$pts - player$ftm) / (2 * player$fga)) * player$Q_ast)
	AST_part <- 2 * ( (team$fgm - player$fgm + 0.5 * (team$fg3m - player$fg3m)) / (team$fgm - player$fgm) ) * 0.5 * ( ((team$pts - team$ftm) - (player$pts - player$ftm)) / (2 * (team$fga - player$fga)) ) * player$ast
	FT_part <- player$ftm
	OR_part <- player$oreb * team$oreb_weight * team$play_pct * (team$pts / (team$fgm + (1 - (1 - team$ftp)^2) * 0.4 * team$fta))

	points_produced <- (FG_part + AST_part + FT_part) * (1 - (team$oreb/team$scoring_poss) * team$oreb_weight * team$play_pct) + OR_part

	if (DEBUG) {
		cat("FG_part = ",FG_part,"\n",sep="")
		cat("AST_part = ",AST_part,"\n",sep="")
		cat("FT_part = ",FT_part,"\n",sep="")
		cat("OR_part = ",OR_part,"\n",sep="")
		cat("IPP = ",points_produced,"\n",sep="")
	}

	return(points_produced)
}

#player$scoring_poss <- nba.isp(team,player)
#player$total_poss <- nba.itp(team,player)
#player$points_produced <- nba.ipp(team,player)
#
#player$ortg <- player$points_produced / player$total_poss * 100
#
#cat("ORtg: ",player$ortg,"\n",sep="")

# to store data
pused <- c()
ortgs <- c()

games.team <- read.csv("lebron.team.csv")
games.opp <- read.csv("lebron.opp.csv")
games.player <- read.csv("lebron.player.csv")

for (i in 1:nrow(games.team)) {
	team <- games.team[i,]
	opp <- games.opp[i,]
	player <- games.player[i,]

	# calculate some needed stats
	# player FT%
	if (player$fta == 0) {
		player$ftp <- 0
	} else {
		player$ftp <- player$ftm/player$fta
	}
	# player Q_ast
	player$Q_5 <- 1.14 * (team$ast - player$ast) / team$fgm
	player$Q_12 <- ( (team$ast/team$min) * player$min * 5 - player$ast ) / ( (team$fgm/team$min) * player$min * 5 - player$fgm )
	player$Q_ast <- (player$min / (team$min/5)) * player$Q_5 + (1 - (player$min / (team$min/5) )) * player$Q_12

	# team FT%
	if (team$fta == 0) {
		team$ftp <- 0
	} else {
		team$ftp <- team$ftm/team$fta
	}
	# team possessions
	team$poss <- team$fga - (team$oreb / (team$oreb+team$dreb)) * (team$fga - team$fgm) * 1.07 + team$to + 0.4 * team$fta
	# team scoring possessions
	team$scoring_poss <- team$fgm + (1 - (1 - team$ftp)^2) * team$fta * 0.4
	# team plays
	team$plays <- team$fga + team$fta * 0.4 + team$to
	# team play%
	team$play_pct <- team$scoring_poss / team$plays
	# team OReb%
	team$oreb_pct <- team$oreb / (team$oreb + opp$dreb)
	# team OReb weight
	team$oreb_weight <- ( (1-team$oreb_pct) * team$play_pct ) / ( (1 - team$oreb_pct) * team$play_pct + team$oreb_pct * (1 - team$play_pct) )

	player$scoring_poss <- nba.isp(team,player)
	player$total_poss <- nba.itp(team,player)
	player$points_produced <- nba.ipp(team,player)

	player$ortg <- player$points_produced / player$total_poss * 100

	pused <- c(pused, player$total_poss / team$poss)
	ortgs <- c(ortgs, player$ortg)

	if (DEBUG) {
		cat("ORtg: ",player$ortg,", Used: ",player$total_poss/team$poss,"\n",sep="")
	}
}

scatter.smooth(ortgs,pused)
